@@ -20,8 +20,8 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
   else if ( (!grepl(":", x.name) && !grepl(",", x.name)) ) {  # not a var list
     if (exists(x.name, where=1)) if (is.data.frame(x)) {
-        data <- x
-        is.df <- TRUE
+      data <- x
+      is.df <- TRUE
     }
   }
 
@@ -98,29 +98,70 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
 
   if (!is.df) nu <- length(unique(na.omit(x.call)))
 
-  if (is.df) .ss.data.frame(data, n.cat, brief, ...) 
+  if (is.df)
+    .ss.data.frame(data, n.cat, brief, ...) 
 
-  else if (is.numeric(x.call)  &&  nu > n.cat)
-     stats <- .ss.numeric(x.call, y.call, data, digits.d, brief, ...)
-
-  else if (is.numeric(x.call) && nu <= n.cat) {
-    cat("\n>>> Variable is numeric, but only has", nu, "<= n.cat =", n.cat, "levels,",
-      "so treat as categorical.\n",
-      "   To obtain the numeric summary, decrease  n.cat  to indicate a lower\n",
-      "   number of unique values such as with function: set.\n", 
-      "   Perhaps make this variable a factor with the R factor function.\n")
-    stats <- .ss.factor(x.call, y.call, brief, digits.d, ...)
+  else if (is.numeric(x.call)) {
+    if (nu > n.cat) { 
+      sk <- NA; kt <- NA; q1 <- NA; q3 <- NA;  qr <- NA;
+      stuff <- .ss.numeric(x.call, y.call, data, digits.d, brief, ...)
+      txsts <- stuff$tx
+      txotl <- .outliers2(x.call)
+    }
+    else {
+      cat("\n>>> Variable is numeric, but only has", nu, "<= n.cat =", n.cat, "levels,",
+        "so treat as categorical.\n",
+        "   To obtain the numeric summary, decrease  n.cat  to indicate a lower\n",
+        "   number of unique values such as with function: set.\n", 
+        "   Perhaps make this variable a factor with the R factor function.\n")
+      stuff <- .ss.factor(x.call, y.call, brief, digits.d, ...)
+    }
   }
 
   # ordered factors have two attributes, "ordered" and "factor"
-  else if (is.factor(x.call))
-     stats <- .ss.factor(x.call, y.call, brief, digits.d, ...)
+  else if (is.factor(x.call)  ||  is.character(x.call)) {
+
+    if (is.factor(x.call)) {
+      stuff <- .ss.factor(x.call, y.call, brief, digits.d, ...)
+      n.dim <- stuff$n.dim
+      if (n.dim == 1) {
+        txttl <- stuff$title
+        txsts <- stuff$tx
+        frq <- stuff$frq
+        prp <- stuff$prp
+      }
+      else if (n.dim == 2) {
+        txttl <- stuff$txttl
+        txfrq <- stuff$txfrq
+        txprp <- stuff$txprp
+        txcol <- stuff$txcol
+        txrow <- stuff$txrow
+      }
+    }
 
   else if (is.character(x.call))
-    if (nlevels(factor(x.call)) < length(x.call)) 
-       stats <- .ss.factor(factor(x.call), by, brief, n.cat, digits.d, ...)
+    if (nlevels(factor(x.call)) < length(x.call)) { 
+      stuff <- .ss.factor(factor(x.call), by, brief, n.cat, digits.d, ...)
+      n.dim <- stuff$n.dim
+      if (n.dim == 1) {
+        txttl <- stuff$title
+        txsts <- stuff$tx
+        frq <- stuff$frq
+        prp <- stuff$prp
+      }
+      else if (n.dim == 2) {
+        txttl <- stuff$txttl
+        txfrq <- stuff$txfrq
+        txprp <- stuff$txprp
+        txcol <- stuff$txcol
+        txrow <- stuff$txrow
+      }
+
+    }
     else cat("\n Appears to contain unique Names or IDs", "\n")
 
+  }
+
   else {
     cat("\n"); stop(call.=FALSE, "\n","------\n",
         "The variable to be analyzed must be numeric or a factor, or have\n",
@@ -128,8 +169,45 @@ function(x=NULL, by=NULL, data=mydata, n.cat=getOption("n.cat"),
         "that can be converted to numerical 0 and 1.\n")
   }
 
-  cat("\n")
-  if (!is.df) invisible(stats)
+  if (!is.df) { 
+
+    if (is.numeric(x.call)) {
+      class(txsts) <- "out_piece"
+      class(txotl) <- "out_piece"
+
+      output <- list(out_stats=txsts, out_outliers=txotl, n=stuff$n,
+           n.miss=stuff$n.miss, mean=stuff$m, sd=stuff$s, skew=stuff$sk,
+           kurtosis=stuff$kt, min=stuff$mn, quartile1=stuff$q1,
+           median=stuff$md, quartile3=stuff$q3, max=stuff$mx, IQR=stuff$qr)
+    }
+
+    else if (is.factor(x.call)  ||  is.character(x.call)) {
+      if (n.dim == 1) {
+        class(txttl) <- "out_piece"
+        class(txsts) <- "out_piece"
+        class(frq) <- "out_piece"
+        class(prp) <- "out_piece"
+        output <- list(out_title=txttl, out_stats=txsts, freq=frq, prop=prp)
+      }
+      else if (n.dim == 2) {
+        if (brief) {
+          class(txttl) <- "out_piece"
+          class(txfrq) <- "out_piece"
+          output <- list(out_title=txttl, out_freq=txfrq)
+        }
+        else {
+          class(txprp) <- "out_piece"
+          class(txcol) <- "out_piece"
+          class(txrow) <- "out_piece"
+          output <- list(out_title=txttl, out_freq=txfrq,
+             out_prop=txprp, out_colsum=txcol, out_rowsum=txrow)
+        }
+      }
+    }
+
+    class(output) <- "out_all"
+    return(output)
+
+  }
+
 }
-
-
