@@ -1,7 +1,8 @@
 Transform <-
 function(data=mydata, quiet=getOption("quiet"), ...) {
 
-  dname <- deparse(substitute(data))
+  # save variable labels (NULL if no labels) 
+  mylabels <- attr(data, which="variable.labels")
 
   # transformations done here into vector e, e[1] the first trans, etc.
   e <- eval(substitute(list(...)), data, parent.frame())
@@ -10,6 +11,8 @@ function(data=mydata, quiet=getOption("quiet"), ...) {
   n.obs <- nrow(data)
 
   if (!quiet) {
+    dname <- deparse(substitute(data))
+
     cat("\n")
     cat("Number of variables of", dname, "to transform:", n.tvars, "\n")
     cat("Number of cases (rows) of ", dname, ": ", n.obs, "\n", sep="")
@@ -80,6 +83,9 @@ function(data=mydata, quiet=getOption("quiet"), ...) {
     cat("\n")
   }
  
+  # restore any variable labels
+  if (!is.null(mylabels)) attr(data, which="variable.labels") <- mylabels
+
   return(data)
 
 }
